==> HyTE-0.0.1.tar.gz: HyTE-0.0.1/setup.py <==
# Preparing imports.
from setuptools import setup, find_packages
import codecs
import os

# Prepare project details.
VERSION = '0.0.1'
DESCRIPTION = 'LLM-based hypothesize-test-evaluate automation.'
LONG_DESCRIPTION = ('A package that allows for LLMs to create hypotheses, test them '
                    'experimentally, and evaluate whether their hypotheses were correct - within '
                    'a loop. As the process loops, the LLMs iterate towards discovey of insights.'
                    )

# Obtain read-me details for long description.
current_location = os.path.abspath(os.path.dirname(__file__))
with codecs.open(os.path.join(current_location, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

# Setting up package details.
setup(
    name="HyTE",
    version=VERSION,
    author="5krus (Eryk Krusinski)",
    author_email="<eryk@krus.co.uk>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['openai'],
    keywords=[
        'python',
        'llm',
        'optimisation',
        'whittle laboratory',
        'reasoning',
        'experimentation'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)

==> HyTE-0.0.2.tar.gz: HyTE-0.0.2/setup.py <==
# Preparing imports.
from setuptools import setup, find_packages
import codecs
import os

# Prepare project details.
VERSION = '0.0.2'
DESCRIPTION = 'LLM-based hypothesize-test-evaluate automation.'
LONG_DESCRIPTION = ('A package that allows for LLMs to create hypotheses, test them '
                    'experimentally, and evaluate whether their hypotheses were correct - within '
                    'a loop. As the process loops, the LLMs iterate towards discovey of insights.'
                    )

# Obtain read-me details for long description.
current_location = os.path.abspath(os.path.dirname(__file__))
with codecs.open(os.path.join(current_location, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

# Setting up package details.
setup(
    name="HyTE",
    version=VERSION,
    author="5krus (Eryk Krusinski)",
    author_email="<eryk@krus.co.uk>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['openai', 'python-dotenv'],
    keywords=[
        'python',
        'llm',
        'optimisation',
        'whittle laboratory',
        'reasoning',
        'experimentation'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
